<?php

namespace Developer\DataTable\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Developer\DataTable\Models\Ex;

class ExPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the ex.
     *
     * @param User $user
     * @param Ex $ex
     *
     * @return bool
     */
    public function view(User $user, Ex $ex)
    {
        if ($user->canDo('data_table.ex.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $ex->user_id;
    }

    /**
     * Determine if the given user can create a ex.
     *
     * @param User $user
     * @param Ex $ex
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('data_table.ex.create');
    }

    /**
     * Determine if the given user can update the given ex.
     *
     * @param User $user
     * @param Ex $ex
     *
     * @return bool
     */
    public function update(User $user, Ex $ex)
    {
        if ($user->canDo('data_table.ex.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $ex->user_id;
    }

    /**
     * Determine if the given user can delete the given ex.
     *
     * @param User $user
     * @param Ex $ex
     *
     * @return bool
     */
    public function delete(User $user, Ex $ex)
    {
        if ($user->canDo('data_table.ex.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $ex->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
