<?php

namespace Developer\DataTable\Providers;

use Illuminate\Support\ServiceProvider;

class DataTableServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'data_table');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'data_table');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('data_table', function ($app) {
            return $this->app->make('Developer\DataTable\DataTable');
        });

        // Bind Ex to repository
        $this->app->bind(
            \Developer\DataTable\Interfaces\ExRepositoryInterface::class,
            \Developer\DataTable\Repositories\Eloquent\ExRepository::class
        );

        $this->app->register(\Developer\DataTable\Providers\AuthServiceProvider::class);
        $this->app->register(\Developer\DataTable\Providers\EventServiceProvider::class);
        $this->app->register(\Developer\DataTable\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['data_table'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/data_table.php')], 'config');

        // Publish public view
        $this->publishes([__DIR__ . '/../../../../resources/views/public'  => base_path('resources/views/vendor/data_table/public')], 'view-public');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views/admin' => base_path('resources/views/vendor/data_table/admin')], 'view-admin');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/data_table')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
